@@ -56,14 +56,21 @@ checkWrapperArgs = function(id, type, mart){
 
 bmRequest <- function(request, ssl.verifypeer = TRUE, verbose = FALSE){
     if(verbose) writeLines(paste("Attempting web service request:\n",request, sep=""))
-    result = tryCatch(getURL(request, ssl.verifypeer = ssl.verifypeer, followlocation = TRUE), 
-                      error = function(e){ 
-                          message("Request to BioMart web service failed.\n", 
-                                  "The BioMart web service you're accessing may be down.\n",
-                                  "Check the following URL and see if this website is available:\n",
-                                  request)
-                      })
-    return(result)
+    #result = tryCatch(getURL(request, ssl.verifypeer = ssl.verifypeer, followlocation = TRUE), 
+    #                  error = function(e){ 
+    #                      message("Request to BioMart web service failed.\n", 
+    #                              "The BioMart web service you're accessing may be down.\n",
+    #                              "Check the following URL and see if this website is available:\n",
+    #                              request)
+    #                  })
+    result <- httr::GET(request, content_type("text/plain"),
+                        set_cookies(.cookies = c(redirect_mirror = 'no')))
+    stop_for_status(result)
+    result2 <- content(result, encoding = "UTF-8")
+    if(is.na(result2)) {
+        result2 <- content(result, encoding = "Latin1")
+    }
+    return(result2)
 }
 
 #######################################################
@@ -113,8 +120,8 @@ listMarts <- function( mart = NULL, host="www.ensembl.org", path="/biomart/marts
         } else {
             stop('Unexpected format to the list of available marts.\n',
                  'Please check the following URL manually, ',
-                'and try ?listMarts for advice.\n',
-                request)
+                 'and try ?listMarts for advice.\n',
+                 request)
         }
     }
     registry = xmlTreeParse(registry, asText=TRUE)
@@ -225,23 +232,24 @@ useMart <- function(biomart, dataset, host = "www.ensembl.org", path = "/biomart
                 biomart = biomart,
                 vschema = marts$vschema[mindex], 
                 host = paste0(host, ":", 
-                              #marts$port[mindex],
                               port,
-                              marts$path[mindex]))#, 
-               # archive = archive)
+                              marts$path[mindex]))
     
     if(length(grep("archive",martHost(mart)) > 0)){
         
         ## hack to work around redirection of most recent mirror URL
         archives <- listEnsemblArchives()
         current_release <- archives[archives$current_release == "*", 'url']
-        mart@host <- stringr::str_replace(mart@host, pattern = current_release, "http://www.ensembl.org")
-        
-        if(length(grep(reqHost,martHost(mart))) == 0){
-            message("Note: requested host was redirected from\n", reqHost, " to " , martHost(mart))
-            message("This often occurs when connecting to the archive URL for the current Ensembl release")
-            message("You can check the current version number using listEnsemblArchives()")
+        if(grepl(mart@host, pattern = current_release)) {
+            mart@host <- stringr::str_replace(mart@host, pattern = current_release, "https://www.ensembl.org")
+            mart@host <- stringr::str_replace(mart@host, pattern = ":80/", ":443/")
         }
+
+        #if(length(grep(reqHost,martHost(mart))) == 0){
+        #    message("Note: requested host was redirected from\n", reqHost, " to " , martHost(mart))
+        #    message("This often occurs when connecting to the archive URL for the current Ensembl release")
+        #    message("You can check the current version number using listEnsemblArchives()")
+        #}
     }
     
     BioMartVersion=bmVersion(mart, verbose=verbose)
@@ -261,7 +269,10 @@ useMart <- function(biomart, dataset, host = "www.ensembl.org", path = "/biomart
 }
 
 listDatasets <- function(mart, verbose = FALSE) {
-    
+    .listDatasets(mart = mart, verbose = verbose, sort = TRUE)
+}
+
+.listDatasets <- function(mart, verbose = FALSE, sort = FALSE) {
     if(missing(mart) || !is(mart, 'Mart'))
         stop("No Mart object given or object not of class 'Mart'")
     
@@ -273,7 +284,6 @@ listDatasets <- function(mart, verbose = FALSE) {
     bmResult = bmRequest(request = request, verbose = verbose)
     con = textConnection(bmResult)
     txt = scan(con, sep="\t", blank.lines.skip=TRUE, what="character", quiet=TRUE, quote = "\"")
-    #txt = tryCatch(scan(request, sep="\t", blank.lines.skip=TRUE, what="character", quiet=TRUE), error = function(e){stop("Request to BioMart web service failed. Verify if you are still connected to the internet.  Alternatively the BioMart web service is temporarily down.")})
     close(con)
     
     ## select visible ("1") table sets
@@ -284,7 +294,8 @@ listDatasets <- function(mart, verbose = FALSE) {
                      version     = I(txt[i+4L]))
     
     ## sort alphabetically
-    res <- res[ order(res$dataset), ]
+    if(sort)
+        res <- res[ order(res$dataset), ]
     rownames(res) <- NULL
     
     return(res)
@@ -318,7 +329,6 @@ bmVersion <- function(mart, verbose=FALSE){
 }
 
 ## Retrieve attributes and filters from web service
-
 bmAttrFilt <- function(type, mart, verbose=FALSE){
     
     ## we choose a separator based on whether 'redirect=no' is present
@@ -377,7 +387,7 @@ bmAttrFilt <- function(type, mart, verbose=FALSE){
 ## have been passed.
 checkDataset <- function(dataset, mart) {
     
-    validDatasets=listDatasets(mart)
+    validDatasets <- .listDatasets(mart, sort = FALSE)
     ## subseting data.frames can produce some weird classes
     ## which aren't character(), so we coerce it here
     dataset <- as.character(dataset)
@@ -422,7 +432,8 @@ getName <- function(x, pos) if(is.null(x[[pos]])) NA else x[[pos]]
 
 listAttributes <- function(mart, page, what = c("name","description","page")) {
     martCheck(mart)
-    if(!missing(page) && !page %in% attributePages(mart)) stop(paste("The chosen page: ",page," is not valid, please use the correct page name using the attributePages function",sep=""))
+    if(!missing(page) && !page %in% attributePages(mart)) 
+        stop("The chosen page: ",page," is not valid, please use the correct page name using the attributePages function")
     attrib=NULL
     if(!missing(page)){
         sel = which(martAttributes(mart)[,"page"] == page)
@@ -496,7 +507,7 @@ getBM <- function(attributes, filters = "", values = "", mart, curl = NULL, chec
         warning("Argument 'values' should not be used when argument 'filters' is a list and will be ignored.")
     if(is.list(filters) && is.null(names(filters)))
         stop("Argument 'filters' must be a named list when sent as a list.")
-    if(!is.list(filters) && filters != "" && missing( values ))
+    if(!is.list(filters) && all(filters != "") && missing( values ))
         stop("Argument 'values' must be specified.")
     
     if(length(filters) > 0 && length(values) == 0)
@@ -569,7 +580,7 @@ getBM <- function(attributes, filters = "", values = "", mart, curl = NULL, chec
         sep <- ifelse(grepl(x = martHost(mart), pattern = ".+\\?.+"), "&", "?")
         
         postRes <- .submitQueryXML(host = paste0(martHost(mart), sep),
-                                query = fullXmlQuery)
+                                   query = fullXmlQuery)
         
         if(verbose){
             writeLines("#################\nResults from server:")
@@ -750,7 +761,7 @@ getLDS <- function(attributes, filters = "", values = "", mart, attributesL, fil
     sep <- ifelse(grepl(x = martHost(mart), pattern = ".+\\?.+"), "&", "?")
     ## POST query
     postRes <- .submitQueryXML(host = paste0(martHost(mart), sep),
-                            query = xmlQuery)
+                               query = xmlQuery)
     
     ## 10-01-2014
     if(length(grep("^Query ERROR", postRes))>0L)
@@ -789,8 +800,8 @@ getXML <- function(host="http://www.ensembl.org/biomart/martservice?", xmlquery)
     ## Deprecated 29-01-2018
     .Deprecated("biomaRt:::.submitQueryXML", 
                 msg = paste0("Function 'getXML()' is deprecated.\n",
-                "Use 'biomaRt:::.submitQueryXML' instead\n",
-                "See help('getXML') for further details"))
+                             "Use 'biomaRt:::.submitQueryXML' instead\n",
+                             "See help('getXML') for further details"))
     
     pf = postForm(host,"query"=xmlquery)
     con = textConnection(pf)
@@ -858,20 +869,37 @@ getSequence <- function(chromosome, start, end, id, type, seqType, upstream, dow
     if(!missing(chromosome) && !missing(id))stop("The getSequence function retrieves sequences given a vector of identifiers specified with the id argument of a type specified by the type argument.  Or alternatively getSequence retrieves sequences given a chromosome, a start and a stop position on the chromosome.  As you specified both a vector of identifiers and chromsomal coordinates. Your query won't be processed.")
     
     if(!missing(chromosome)){
-        if(!missing(start) && missing(end))stop("You specified a chromosomal start position but no end position.  Please also specify a chromosomal end position.")
-        if(!missing(end) && missing(start))stop("You specified a chromosomal end position but no start position.  Please also specify a chromosomal start position.")
+        if(!missing(start) && missing(end))
+            stop("You specified a chromosomal start position but no end position.  Please also specify a chromosomal end position.")
+        if(!missing(end) && missing(start))
+            stop("You specified a chromosomal end position but no start position.  Please also specify a chromosomal start position.")
         if(!missing(start)){ start = as.integer(start)
         end = as.integer(end)
         }
         if(missing(upstream) && missing(downstream)){
-            sequence = getBM(c(seqType,type), filters = c("chromosome_name","start","end"), values = list(chromosome, start, end), mart = mart, checkFilters = FALSE, verbose=verbose)
+            sequence = getBM(c(seqType,type), 
+                             filters = c("chromosome_name","start","end"), 
+                             values = list(chromosome, start, end), 
+                             mart = mart, 
+                             checkFilters = FALSE, 
+                             verbose=verbose)
         }
         else{
             if(!missing(upstream) && missing(downstream)){
-                sequence = getBM(c(seqType,type), filters = c("chromosome_name","start","end","upstream_flank"), values = list(chromosome, start, end, upstream), mart = mart, checkFilters = FALSE, verbose=verbose)
+                sequence = getBM(c(seqType,type), 
+                                 filters = c("chromosome_name","start","end","upstream_flank"), 
+                                 values = list(chromosome, start, end, upstream), 
+                                 mart = mart, 
+                                 checkFilters = FALSE, 
+                                 verbose=verbose)
             }
             if(!missing(downstream) && missing(upstream)){
-                sequence = getBM(c(seqType,type), filters = c("chromosome_name","start","end","downstream_flank"), values = list(chromosome, start, end, downstream), mart = mart, checkFilters = FALSE, verbose = verbose)
+                sequence = getBM(c(seqType,type), 
+                                 filters = c("chromosome_name","start","end","downstream_flank"), 
+                                 values = list(chromosome, start, end, downstream), 
+                                 mart = mart, 
+                                 checkFilters = FALSE, 
+                                 verbose = verbose)
             }
             if(!missing(downstream) && !missing(upstream)){
                 stop("Currently getSequence only allows the user to specify either an upstream of a downstream argument but not both.")
@@ -906,7 +934,7 @@ getSequence <- function(chromosome, start, end, id, type, seqType, upstream, dow
 #export FASTA      #
 ####################
 
-exportFASTA <- function( sequences, file ){
+exportFASTA <- function( sequences, file ) {
     if( missing( sequences ) || class( sequences ) != "data.frame"){
         stop("No data.frame given to write FASTA.  The data.frame should be the output of the getSequence function.");
     }
