@@ -90,7 +90,7 @@
                          "that not fulfill the requirement should be retrieved.", 
                          call. = FALSE)
                 val <- ifelse(values[[filter]], yes = 0, no = 1)
-                val <- paste0("' excluded = \"", val, "\" ")
+                val <- paste0("\" excluded = \"", val, "\" ")
                 
             } else { 
                 ## otherwise the filter isn't boolean, or doesn't exist
@@ -98,9 +98,11 @@
                 if(is.numeric(values[[filter]])) 
                     values[[filter]] <- as.integer(values[[filter]])
                 val <- paste0(values[[filter]], collapse = ",")
-                val <- paste0("' value = '", val, "' ")
+                ## convert " to ' to avoid truncating the query string
+                val <- gsub(x = val, pattern = "\"", replacement = "'", fixed = TRUE)
+                val <- paste0('" value = "', val, '" ')
             }
-            filterXML <- paste0("<Filter name = '", filter, val, "/>")
+            filterXML <- paste0("<Filter name = \"", filter, val, "/>")
             return(filterXML)
         }, FUN.VALUE = character(1), 
         filterChunk, mart,
@@ -169,16 +171,16 @@
 .submitQueryXML <- function(host, query) {
     res <- httr::POST(url = host,
                       body = list('query' = query),
-                      set_cookies(.cookies = c(redirect_mirror = 'no')),
-                      timeout(600))
+                     # set_cookies(.cookies = c(redirect_mirror = 'no')),
+                      timeout(300))
 
     ## now we set the redirection cookie, this code should never be executed
-    if(res$all_headers[[1]]$status == 302) {
+    if(status_code(res) == 302) {
         host <- stringr::str_match(string = res$all_headers[[1]]$headers$location,
                                pattern = "//([a-zA-Z./]+)\\??;?redirectsrc")[,2]
         res <- httr::POST(url = host,
                           body = list('query' = query),
-                          config = list(timeout(600)))
+                          config = list(timeout(300)))
     }
     ## content() prints a message about encoding not being supplied 
     ## for ensembl.org - no default, so we suppress it
@@ -260,3 +262,36 @@ searchFilters <- function(mart, pattern) {
 }
 
 
+## Some filters have a predefined list of options that can be selected.
+## This function lets us search those values, given a specified filter.
+searchFilterValues <- function(mart, filter, pattern) {
+  
+  if(missing(mart))
+    stop("Argument 'mart' must be specified")
+  if(missing(filter))
+    stop("Argument 'filter' must be specified")
+  if(missing(pattern)) 
+    pattern = ".*"
+  
+  ## first get all filters & their options, then reduce to what's requested
+  filters <- listFilters(mart, what = c("name", "options"))
+  filters <- filters[ filters$name == filter, ]
+  if(nrow(filters) == 0) { 
+    stop("Filter '", filter, "' not found.")
+  }
+  options <- gsub(filters$options, pattern = "^\\[|\\]$", replacement = "")
+  options <- strsplit(options, split = ",", fixed = TRUE)[[1]]
+  
+  res <- grep(x = options, pattern = pattern, 
+              ignore.case = TRUE, value = TRUE)
+  
+  if(length(res) == 0)
+    message('No matching values found')
+  else
+    res
+}
+
+
+listFilterValues <- function(mart, filter) {
+    searchFilterValues(mart = mart, filter = filter)
+}
